# MessageEndpoint

A single address on which we can notify a user (e.g. phone#, push context, ...)
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metadata** | [**MessageEndpointMetadata**](MessageEndpointMetadata.md) |  | [optional] 
**spec** | [**MessageEndpointSpec**](MessageEndpointSpec.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


